pub struct ScopeSpec {
pub paths: PathSource,
pub globs: bool,
pub skip: usize,
pub flag_args: Vec<String>,
pub path_flags: Vec<String>,
pub recursive_flags: Vec<String>,
}Fields
paths: PathSourceglobs: boolskip: usizeLeading positional arguments that are not paths (sed scripts, chmod modes) and must be dropped before scope extraction.
flag_args: Vec<String>Flags that consume the following argument (truncate -s 0): that
argument is not a path and must not enter the scope.
path_flags: Vec<String>Flags whose value is a target path to snapshot, in either the
separate (-o out.txt) or attached (--output=out.txt) form.
recursive_flags: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ScopeSpec
impl<'de> Deserialize<'de> for ScopeSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more